import * as RD from '@devexperts/remote-data-ts';
import * as E from 'fp-ts/Eq';
/**
 * Inserts data into a supabase table.
 * @example
 * ```tsx
 * const [result, execute] = useInsert<Foo>("foo");
 *
 * pipe(
 *   result,
 *   RD.fold(
 *     () => (
 *       <button
 *         onClick={() =>
 *           execute({
 *             bar: "baz",
 *           })
 *         }
 *       >
 *         Click me
 *       </button>
 *     ),
 *     () => <div>Loading...</div>,
 *     (e) => <div>Error {e}</div>,
 *     (rows) => (
 *       <div>
 *         Inserted
 *         {rows.map((row) => (
 *           <div key={row.id}>{row.bar}</div>
 *         ))}
 *       </div>
 *     )
 *   )
 * );
 * ```
 * @param tableName - The name of the table you want to insert into
 * @param eq - An Eq for your data type
 * @returns The result of the request and a function to execute the insertion
 */
export declare const useInsert: <T = unknown>(tableName: string, eq?: E.Eq<readonly T[]>) => readonly [RD.RemoteData<string, readonly T[]>, (values: Partial<T> | Partial<T>[]) => Promise<void>];
