import * as RD from '@devexperts/remote-data-ts';
import * as E from 'fp-ts/Eq';
import { Filter } from '../types';
export declare type UseTableResponse<T = unknown> = readonly [RD.RemoteData<string, readonly T[]>, () => Promise<void>];
/**
 * Gets many rows from a supabase table.
 * @example
 * ```tsx
 * const filter = useFilter<Foo>((query) => query.gt("id", "5"));
 * const [result, reexecute] = useTable<Foo>("foo", "id, bar", filter);
 * pipe(
 *   result,
 *   RD.fold3(
 *     () => <div>Loading...</div>,
 *     (e) => <div>Error {e}</div>,
 *     (rows) => (
 *       <div>
 *         {rows.map((row) => (
 *           <div key={row.id}>{row.bar}</div>
 *         ))}
 *       </div>
 *     )
 *   )
 * );
 * ```
 * @param tableName - The table name to get rows from
 * @param selectArgs - Arguments for a select query
 * @param filter - A filter for your query
 * @param eq - An Eq for your data type
 * @returns Rows that match your filter, or all rows if there is no filter, and a function to reexecute the query
 */
export declare const useTable: <T = unknown>(tableName: string, selectArgs?: string, filter?: Filter<T> | undefined, eq?: E.Eq<readonly T[]>) => UseTableResponse<T>;
